@@ -331,7 +331,7 @@ def unban_user(room_real_id: int, block_id: int, verify: utils.Verify = None):
     return resp
 
 
-def connect_all_livedanmaku(*livedanmaku_classes):
+def connect_all_LiveDanmaku(*livedanmaku_classes):
     """
     同时连接多个直播间
     :param livedanmaku_classes: LiveDanmaku类动态参数
@@ -345,7 +345,9 @@ def connect_all_livedanmaku(*livedanmaku_classes):
     async def run():
         for task in tasks:
             await task
+
     asyncio.get_event_loop().run_until_complete(run())
+    asyncio.get_event_loop().run_forever()
 
 
 class LiveDanmaku(object):
@@ -362,12 +364,13 @@ class LiveDanmaku(object):
     DATAPACK_TYPE_VERIFY = 7
     DATAPACK_TYPE_VERIFY_SUCCESS_RESPONSE = 8
 
-    def __init__(self, room_display_id: int, debug: bool = False, use_wss: bool = True,
-                 verify: utils.Verify = None):
+    def __init__(self, room_display_id: int, debug: bool = False, use_wss: bool = True, should_reconnect: bool = True
+                 , verify: utils.Verify = None):
         self.verify = verify
         self.room_real_id = room_display_id
         self.room_display_id = room_display_id
         self.__use_wss = use_wss
+        self.__event_loop = asyncio.get_event_loop()
         # logging
         self.logger = logging.getLogger(f"LiveDanmaku_{self.room_display_id}")
         self.logger.setLevel(logging.DEBUG if debug else logging.INFO)
@@ -377,15 +380,47 @@ class LiveDanmaku(object):
 
         self.__event_handlers = {}
         self.__websocket = None
-        self.__has_connected = False
+        # 连接状态，0未连接，1已连接，3已正常断开，-1异常断开
+        self.__connected_status = 0
         self.__conf = None
 
-    def connect(self, return_task: bool = False):
+        # 重连设置
+        self.should_reconnect = should_reconnect
+
+        self.__heartbeat_task = None
+        self.__is_single_room = False
+
+    def connect(self, return_coroutine: bool = False):
         """
         连接直播间
         :return:
         """
-        assert not self.__has_connected, exceptions.LiveException("已连接直播间，不可重复连接")
+        if self.__connected_status == 1:
+            raise exceptions.LiveException("已连接直播间，不可重复连接")
+        if return_coroutine:
+            self.__is_single_room = False
+            return self.__main()
+        else:
+            self.__is_single_room = True
+            asyncio.get_event_loop().run_until_complete(self.__main())
+            asyncio.get_event_loop().run_forever()
+
+    def disconnect(self):
+        """
+        断开连接
+        :return:
+        """
+        self.__connected_status = 2
+        asyncio.gather(self.__ws.close())
+
+    def get_connect_status(self):
+        return self.__connected_status
+
+    async def __main(self):
+        """
+        入口
+        :return:
+        """
         # 获取真实房间号
         self.logger.debug("正在获取真实房间号")
         self.room_real_id = get_room_play_info(room_display_id=self.room_real_id, verify=self.verify)["room_id"]
@@ -395,29 +430,6 @@ class LiveDanmaku(object):
         self.__conf = get_chat_conf(room_real_id=self.room_real_id, verify=self.verify)
         self.logger.debug("聊天服务器配置获取成功")
         # 连接直播间
-        loop = asyncio.get_event_loop()
-        if return_task:
-            task = loop.create_task(self.__main())
-            return task
-        else:
-            loop.run_until_complete(self.__main())
-            return None
-
-    def disconnect(self):
-        """
-        断开连接
-        :return:
-        """
-        asyncio.gather(self.__ws.close())
-
-    def has_connected(self):
-        return self.__has_connected
-
-    async def __main(self):
-        """
-        入口
-        :return:
-        """
         self.logger.debug("准备连接直播间")
         for host in self.__conf["host_server_list"]:
             port = host['wss_port'] if self.__use_wss else host['ws_port']
@@ -428,7 +440,6 @@ class LiveDanmaku(object):
                 async with websockets.connect(uri) as ws:
                     self.__ws = ws
                     self.logger.debug(f"连接主机成功, 准备发送认证信息")
-                    self.__has_connected = True
                     uid = None
                     if self.verify is not None:
                         if self.verify.has_sess():
@@ -441,11 +452,13 @@ class LiveDanmaku(object):
                                   "clientver": "1.17.0", "type": 2, "key": self.__conf["token"]}
                     data = json.dumps(verifyData).encode()
                     await self.__send(data, LiveDanmaku.PROTOCOL_VERSION_HEARTBEAT, LiveDanmaku.DATAPACK_TYPE_VERIFY)
+                    self.__connected_status = 1
                     await self.__loop()
-                    break
+                    return
             except websockets.ConnectionClosedError:
                 self.logger.warning(f"连接失败，准备尝试下一个地址")
         else:
+            self.__connected_status = -1
             self.logger.error(f"所有主机连接失败，程序终止")
 
     async def __loop(self):
@@ -453,13 +466,32 @@ class LiveDanmaku(object):
         循环收取数据
         :return:
         """
-        asyncio.create_task(self.__heartbeat())
+        heartbeat_task = asyncio.create_task(self.__heartbeat())
+        self.__heartbeat_task = heartbeat_task
         while True:
             try:
                 data = await self.__recv()
             except websockets.ConnectionClosed:
-                self.logger.warning("连接被断开")
-                self.__has_connected = False
+                callback_info = {
+                    'room_display_id': self.room_display_id,
+                    'room_real_id': self.room_real_id,
+                    "type": "DISCONNECT",
+                    "data": self.__connected_status
+                }
+                handlers = self.__event_handlers.get("DISCONNECT", []) + self.__event_handlers.get("ALL", [])
+                for handler in handlers:
+                    asyncio.create_task(self.__run_as_asynchronous_func(handler, callback_info))
+                if self.__connected_status == 2:
+                    self.logger.info("连接正常断开")
+                    if self.__is_single_room:
+                        asyncio.get_event_loop().stop()
+                else:
+                    self.__connected_status = -1
+                    self.logger.warning("连接被异常断开")
+                    if self.should_reconnect:
+                        asyncio.create_task(self.connect(True))
+                if self.__heartbeat_task is not None:
+                    self.__heartbeat_task.cancel()
                 break
             self.logger.debug(f"收到信息：{data}")
             for info in data:
@@ -500,7 +532,7 @@ class LiveDanmaku(object):
         :return:
         """
         HEARTBEAT = base64.b64decode("AAAAHwAQAAEAAAACAAAAAVtvYmplY3QgT2JqZWN0XQ==")
-        while self.__has_connected:
+        while self.__connected_status == 1:
             self.logger.debug("发送心跳包")
             await self.__ws.send(HEARTBEAT)
             await asyncio.sleep(30.0)
@@ -620,9 +652,13 @@ class LiveDanmaku(object):
         常见事件名：
         DANMU_MSG: 用户发送弹幕
         SEND_GIFT: 礼物
+        COMBO_SEND：礼物连击
+        GUARD_BUY：续费大航海
+        SUPER_CHAT_MESSAGE：醒目留言（SC）
+        SUPER_CHAT_MESSAGE_JPN：醒目留言（带日语翻译？）
         WELCOME: 老爷进入房间
         WELCOME_GUARD: 房管进入房间
-        NOTICE_MSG: 系统通知
+        NOTICE_MSG: 系统通知（全频道广播之类的）
         PREPARING: 直播准备中
         LIVE: 直播开始
         ROOM_REAL_TIME_MESSAGE_UPDATE: 粉丝数等更新
@@ -633,6 +669,7 @@ class LiveDanmaku(object):
         本模块自定义事件：
         VIEW: 直播间人气更新
         ALL: 所有事件
+        DISCONNECT: 断开连接（传入连接状态码参数）
         """
         def decoration(func):
             upper_name = name.upper()
@@ -650,4 +687,4 @@ class LiveDanmaku(object):
 """
 なにせ高性能ですから！（このAPIを指す）
 ーー「ATRI」
-"""
\ No newline at end of file
+"""
